pub struct PlinkoPin {
pub row: i64,
pub column: i64,
}Expand description
Колышек, которого коснулся шарик: ряд и колонка внутри ряда.
В ряду row колонки нумеруются 0..=row.
Fields
row: i64column: i64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for PlinkoPin
impl<'de> Deserialize<'de> for PlinkoPin
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlinkoPin
impl JsonSchema for PlinkoPin
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for PlinkoPin
impl Tsify for PlinkoPin
const DECL: &'static str = "/**\n * \u{41a}\u{43e}\u{43b}\u{44b}\u{448}\u{435}\u{43a}, \u{43a}\u{43e}\u{442}\u{43e}\u{440}\u{43e}\u{433}\u{43e} \u{43a}\u{43e}\u{441}\u{43d}\u{443}\u{43b}\u{441}\u{44f} \u{448}\u{430}\u{440}\u{438}\u{43a}: \u{440}\u{44f}\u{434} \u{438} \u{43a}\u{43e}\u{43b}\u{43e}\u{43d}\u{43a}\u{430} \u{432}\u{43d}\u{443}\u{442}\u{440}\u{438} \u{440}\u{44f}\u{434}\u{430}.\n * \u{412} \u{440}\u{44f}\u{434}\u{443} `row` \u{43a}\u{43e}\u{43b}\u{43e}\u{43d}\u{43a}\u{438} \u{43d}\u{443}\u{43c}\u{435}\u{440}\u{443}\u{44e}\u{442}\u{441}\u{44f} `0..=row`.\n */\nexport interface PlinkoPin {\n row: number;\n column: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Copy for PlinkoPin
impl Eq for PlinkoPin
impl StructuralPartialEq for PlinkoPin